# vitalpy

Welcome to vitalpy - essential tools for programming in Python!

## Installation

Linux / macOS (python3):

``` zsh
python3 -m pip install vitalpy
```

Linux  / macOS (python2):

``` zsh
python -m pip install vitalpy
```

Windows:

``` zsh
py -m pip install vitalpy
```

## Docs

[vitalpy documentation](http://123web.uk/dcoded/python/docs)
